% ----------------------
% SS.m
% ----------------------
% computes steady state and fills the values for year 't'
% in:   DF,w,taxinstrument
% out:  resid
% ----------------------

function resid = SS(inputs)

global t nag nwg rho g G gamv sigma psi nu
global Y Div w I J V K A C TB DF edy r P B
global A_0 alpha LS LD edl ellv N delta thetav
global epsl parlv0 parlv1 parpv0 epsp hcutv partv yv notretv
global tauWv tauW tauF taul tauprof tauprofdeduct tauC bv
global pc TaxF Exp Rev PB DG cG CG DGtarget edg budget_bal
global DF0 w0 tauWiv0 tauFi0 tauprof0 taul0 cG0 eda edv tauC0 
global Hv Cv Qv Av Omegav ivv pv Nv ediv abv ab0 ab edab shareAv
global tauWi tauWiv tauWc tauWcv tauFi tauFc

DF(t)    = DF0*inputs(1);
w(t)     = w0*inputs(2);

if budget_bal == 1; tauWiv(:,t) = tauWiv0+(inputs(3)-1); end
if budget_bal == 2; tauFi(t) = tauFi0+(inputs(3)-1); end
if budget_bal == 3; tauC(t) = tauC0+(inputs(3)-1); end
if budget_bal == 4; taul(t) = taul0+(inputs(3)-1); end
if budget_bal == 5; tauprof(t) = tauprof0+(inputs(3)-1); end
if budget_bal == 6; cG(t) = cG0+(inputs(3)-1); end

% accidental bequest
ab(t)       = ab0*inputs(4);
abv(:,t)    = ab(t)/N(t).*ones(nag,1);

DG(t)       = DGtarget(t); % debt-rule
pc(t)       = 1+tauC(t);

% recalculated total charges
tauWv(:,t)  = tauWiv(:,t)+tauWcv(:,t)-nu.*tauWiv(:,t).*tauWcv(:,t);
tauF(t)     = tauFi(t)+tauFc(t);

% DEMOGRAPHY
% is computed separately in compdemo.m or recompdemo.m

CG(t)    = cG(t)*N(t);

% RETIREMENT
% indicator for retirement
notretv(:,t)                = zeros(nag,1);
notretv(1:floor(nwg(t)),t)  = ones(floor(nwg(t)),1);
notretv(floor(nwg(t))+1,t)  = nwg(t)-floor(nwg(t));

% HOURS SUPPLY
ellv(:,t)   = (((1-tauWv(:,t)).*w(t).*thetav(:,t)./pc(t))./parlv0).^epsl;
dis_ellv  = parlv0.*(epsl./(1+epsl)).*ellv(:,t).^((1+epsl)./epsl)-parlv1;

% PARTICIPATION
hcutv(:,t)  = ((1-tauWv(:,t)).*w(t).*ellv(:,t).*thetav(:,t)-bv(:,t))./pc(t)-dis_ellv;
partv(:,t)  = 1-hcutv(:,t).^(-epsp).*parpv0.^epsp;
hexpv       = 1./partv(:,t).*epsp./(1+epsp).*(parpv0.^epsp.*hcutv(:,t).^(1-epsp)-parpv0);
dis_totv    = notretv(:,t).*(partv(:,t).*dis_ellv-(1-partv(:,t)).*hexpv);

% TOTAL LABOR SUPPLY
LS(t)    = sum(notretv(:,t).*partv(:,t).*ellv(:,t).*thetav(:,t).*Nv(:,t));

% PRODUCTION
uck      = (r(t)+delta*(1-tauprofdeduct(t)*tauprof(t)))/(1-tauprof(t));
K(t)     = LS(t)*(alpha*A_0/uck)^(1/(1-alpha));
Y(t)     = A_0*K(t)^alpha*LS(t)^(1-alpha);
LD(t)    = Y(t)*(1-alpha)/((1+tauF(t))*w(t));

% INVESTMENT
I(t)     = (delta+g)*K(t);
J(t)     = 1/2*psi*K(t)*(I(t)/K(t)-delta-g)^2;

% FIRM VALUE
TaxF(t)  = tauprof(t)*(Y(t)-(1+tauF(t))*w(t)*LD(t)-tauprofdeduct(t)*(J(t)+delta*K(t)));
Div(t)   = Y(t)-(1+tauF(t))*w(t)*LD(t)-I(t)-J(t)-TaxF(t);
V(t)     = (1+r(t))/(r(t)-g)*Div(t);

% CONSUMPTION AND SAVINGS
yv(:,t)  = notretv(:,t).*(partv(:,t).*(1-tauWv(:,t)).*w(t).*ellv(:,t).*thetav(:,t)+(1-partv(:,t)).*bv(:,t))+(1-notretv(:,t)).*(1-tauWiv(:,t)).*pv(:,t)-taul(t);

% rescaling of intervivo-transfers
% is computed separately in compdemo.m or recompdemo.m

% marginal propensity to consume, human wealth, intervivo transfer wealth
% solve backwards in age
Omegav(nag,t) = 1;
Hv(nag,t)     = yv(nag,t)-dis_totv(nag).*pc(t)+ivv(nag,t)+abv(nag,t);
    
for i=(nag-1):-1:1
    Omegav(i,t) = 1+(1/(1+rho)*gamv(i,t))^sigma.*((1+r(t))*(pc(t)/pc(t)))^(sigma-1)*Omegav(i+1,t);
    Hv(i,t)     = yv(i,t)-dis_totv(i)*pc(t)+ivv(i,t)+abv(i,t)+G*Hv(i+1,t)/(1+r(t));
end
    
% assets and consumption
% solve forward in age
Av(1,t)  = 0;
Qv(1,t)  = (Av(1,t)+Hv(1,t))/(pc(t)*Omegav(1,t));
Cv(1,t)  = Qv(1,t)+dis_totv(1);
    
for i=2:nag
    Av(i,t)  = (1+r(t))*(Av(i-1,t)+yv(i-1,t)+ivv(i-1,t)+abv(i-1,t)-pc(t)*Cv(i-1,t))/G;
    Qv(i,t)  = (Av(i,t)+Hv(i,t))/(pc(t)*Omegav(i,t));
    Cv(i,t)  = Qv(i,t)+dis_totv(i);
end
Savv     = Av(:,t)+yv(:,t)+ivv(:,t)+abv(:,t)-pc(t)*Cv(:,t);

% AGGREGATION
A(t)     = Nv(:,t)'*Av(:,t);        % = sum(Av(:,t).*Nv(:,t));
shareAv(:,t)= (Av(:,t).*Nv(:,t))./A(t);
C(t)     = Nv(:,t)'*Cv(:,t);        % = sum(Cv(:,t).*Nv(:,t));
B(t)     = Nv(:,t)'*(notretv(:,t).*(1-partv(:,t)).*bv(:,t));    % expend benefits
P(t)     = Nv(:,t)'*((1-notretv(:,t)).*pv(:,t));                % expend pensions
tauW(t)  = Nv(:,t)'*(tauWv(:,t).*notretv(:,t).*partv(:,t).*ellv(:,t).*thetav(:,t))/LS(t);
tauWi(t) = Nv(:,t)'*(tauWiv(:,t).*notretv(:,t).*partv(:,t).*ellv(:,t).*thetav(:,t))/LS(t);
tauWc(t) = Nv(:,t)'*(tauWcv(:,t).*notretv(:,t).*partv(:,t).*ellv(:,t).*thetav(:,t))/LS(t);

% TRADE BALANCE AND FOREIGN ASSETS
TB(t)    = -DF(t)*(r(t)-g)/(1+r(t));

% GOVERNMENT
Exp(t)   = CG(t)+B(t)+P(t);
Rev(t)   = TaxF(t)+(tauF(t)*LD(t)+tauW(t)*LS(t))*w(t)+taul(t)*N(t)+tauC(t)*C(t)+Nv(:,t)'*((1-notretv(:,t)).*tauWiv(:,t).*pv(:,t));
PB(t)    = DG(t)*(r(t)-g)/(1+r(t));

% EXCESS DEMANDS
edy(t)   = I(t)+J(t)+C(t)+CG(t)+TB(t)-Y(t);
edl(t)   = LD(t)-LS(t);
edg(t)   = Rev(t)-Exp(t)-PB(t);
eda(t)   = DF(t)+DG(t)+V(t)-A(t);
ediv(t)  = -Nv(:,t)'*ivv(:,t);
edab(t)  = Nv(:,t)'*((1-gamv(:,t)).*Savv)-ab(t);

% WALRAS LAW
edv(t)   = edy(t)+w(t)*edl(t)+(r(t)-g)/(1+r(t))*eda(t)+edg(t)+ediv(t)+edab(t);
if abs(edv(t))> 1e-10; error('Error in SS.m: Walras Law does not hold!'); end

resid(1,1) = edy(t);
resid(2,1) = edl(t);
resid(3,1) = edg(t);
resid(4,1) = edab(t);

end