% ----------------------
% TE.m
% ----------------------
% computes the temporary equilibrium for the global time 't'
% in:   w,taxinstrument
% out:  resid
% ----------------------

function resid = TE(inputs)

global t nag nwg rho g G sigma gamv psi nu
global Y Div w I J V K C TB DF A edy r
global A_0 alpha LS LD edl ellv N delta P B
global epsl parlv0 parlv1 parpv0 epsp hcutv partv yv
global tauW tauF taul tauprof tauprofdeduct tauC bv pv
global pc TaxF Exp Rev PB DG cG CG DGtarget edg budget_bal
global w0 tauWiv0 tauFi0 tauprof0 taul0 cG0 eda edv tauC0
global Hv Omegav Qv Cv Nv tauWv Av ivv notretv thetav ediv abv edab ab ab0
global shareAv tauWi tauWc tauWiv tauWcv tauFi tauFc

w(t)    = w0*inputs(1);

if budget_bal == 1; tauWiv(:,t) = tauWiv0+(inputs(2)-1); end
if budget_bal == 2; tauFi(t) = tauFi0+(inputs(2)-1); end
if budget_bal == 3; tauC(t) = tauC0+(inputs(2)-1); end
if budget_bal == 4; taul(t) = taul0+(inputs(2)-1); end
if budget_bal == 5; tauprof(t) = tauprof0+(inputs(2)-1); end
if budget_bal == 6; cG(t) = cG0+(inputs(2)-1); end

% accidental bequest
ab(t)       = ab0*inputs(3);
abv(:,t)    = ab(t)/N(t).*ones(nag,1);

DG(t+1)     = DGtarget(t+1); % debt-rule

pc(t)       = 1+tauC(t);
pc(t+1)     = 1+tauC(t+1);
CG(t)       = cG(t)*N(t);

% recalculated total charges
tauWv(:,t)  = tauWiv(:,t)+tauWcv(:,t)-nu.*tauWiv(:,t).*tauWcv(:,t);
tauF(t)     = tauFi(t)+tauFc(t);

% DEMOGRAPHY
% is computed separately in recompdemo.m

% RETIREMENT
% indicator for retirement
notretv(:,t)                = zeros(nag,1);
notretv(1:floor(nwg(t)),t)  = ones(floor(nwg(t)),1);
notretv(floor(nwg(t))+1,t)  = nwg(t)-floor(nwg(t));

% HOURS SUPPLY
ellv(:,t)   = (((1-tauWv(:,t)).*w(t).*thetav(:,t)./pc(t))./parlv0).^epsl;
dis_ellv    = parlv0.*(epsl./(1+epsl)).*ellv(:,t).^((1+epsl)./epsl)-parlv1;

% PARTICIPATION
hcutv(:,t)   = ((1-tauWv(:,t)).*w(t).*ellv(:,t).*thetav(:,t)-bv(t))./pc(t)-dis_ellv;
partv(:,t)   = 1-hcutv(:,t).^(-epsp).*parpv0.^epsp;
hexpv        = 1./partv(:,t).*epsp/(1+epsp).*(parpv0.^epsp.*hcutv(:,t).^(1-epsp)-parpv0);
dis_totv     = notretv(:,t).*(partv(:,t).*dis_ellv-(1-partv(:,t)).*hexpv);

% TOTAL LABOR SUPPLY
LS(t)    = sum(notretv(:,t).*partv(:,t).*ellv(:,t).*thetav(:,t).*Nv(:,t));

% PRODUCTION
Y(t)    = A_0*K(t)^alpha*LS(t)^(1-alpha);
LD(t)   = ((1-alpha)*A_0/((1+tauF(t))*w(t)))^(1/alpha)*K(t);

% INVESTMENT
psi2    = (1-tauprofdeduct(t)*tauprof(t))*psi;
a1      = psi2/K(t);
a2      = (1-(delta+g)*psi2)+(1-delta)*psi2;
a3      = (1-delta)*(1-(delta+g)*psi2)*K(t)-G*V(t+1)/(1+r(t+1));
I(t)    = (-a2+sqrt(a2^2-4*a1*a3))/(2*a1);
J(t)    = 1/2*psi*K(t)*(I(t)/K(t)-delta-g)^2;
K(t+1)  = (I(t)+(1-delta)*K(t))/G;

% FIRM VALUE
TaxF(t)  = tauprof(t)*(Y(t)-(1+tauF(t))*w(t)*LD(t)-tauprofdeduct(t)*(J(t)+delta*K(t)));
Div(t)   = Y(t)-(1+tauF(t))*w(t)*LD(t)-I(t)-J(t)-TaxF(t);
V(t)     = Div(t)+G*V(t+1)/(1+r(t+1));

% CONSUMPTION AND SAVINGS
yv(:,t)  = notretv(:,t).*(partv(:,t).*(1-tauWv(:,t)).*w(t).*ellv(:,t).*thetav(:,t)+(1-partv(:,t)).*bv(:,t))+(1-notretv(:,t)).*(1-tauWiv(:,t)).*pv(:,t)-taul(t);

% rescaling of intervivo-transfers
% is computed separately in recompdemo.m

% marginal propensity to consume, human wealth, intervivo transfer wealth
% solve backwards in age
Omegav(nag,t)       = 1;
Omegav(1:(nag-1),t) = 1+(1/(1+rho)*gamv(1:(nag-1),t)).^sigma.*((1+r(t+1))*(pc(t)/pc(t+1)))^(sigma-1).*Omegav(2:nag,t+1);
Hv(nag,t)           = yv(nag,t)-dis_totv(nag).*pc(t)+ivv(nag,t)+abv(nag,t);
Hv(1:(nag-1),t)     = yv(1:(nag-1),t)-dis_totv(1:(nag-1))*pc(t)+ivv(1:(nag-1),t)+abv(1:(nag-1),t)+G*Hv(2:nag,t+1)/(1+r(t+1));

% assets and consumption
A(t)     = V(t)+DF(t)+DG(t);
Av(:,t)  = shareAv(:,t).*A(t)./Nv(:,t);
Qv(:,t)  = (Av(:,t)+Hv(:,t))./(pc(t)*Omegav(:,t));
Cv(:,t)  = Qv(:,t)+dis_totv(:);

% solve assets forward in age
Av(1,t+1)       = 0;
Av(2:nag,t+1)   = (1+r(t+1))*(Av(1:(nag-1),t)+yv(1:(nag-1),t)+ivv(1:(nag-1),t)+abv(1:(nag-1),t)-pc(t)*Cv(1:(nag-1),t))/G;

Savv     = Av(:,t)+yv(:,t)+ivv(:,t)+abv(:,t)-pc(t)*Cv(:,t);

% AGGREGATION
A(t+1)   = Nv(:,t+1)'*Av(:,t+1);  % = sum(Av(:,t+1).*Nv(:,t+1));
shareAv(:,t+1) = (Av(:,t+1).*Nv(:,t+1))./A(t+1);
if any(isnan(shareAv(:,t)))==1 error('Error in TE: NaN asset shares'); end
C(t)     = Nv(:,t)'*Cv(:,t);      % = sum(Cv(:,t).*Nv(:,t));
B(t)     = Nv(:,t)'*(notretv(:,t).*(1-partv(:,t)).*bv(:,t));    % expend benefits
P(t)     = Nv(:,t)'*((1-notretv(:,t)).*pv(:,t));                % expend pensions
tauW(t)  = Nv(:,t)'*(tauWv(:,t).*notretv(:,t).*partv(:,t).*ellv(:,t).*thetav(:,t))/LS(t);
tauWi(t) = Nv(:,t)'*(tauWiv(:,t).*notretv(:,t).*partv(:,t).*ellv(:,t).*thetav(:,t))/LS(t);
tauWc(t) = Nv(:,t)'*(tauWcv(:,t).*notretv(:,t).*partv(:,t).*ellv(:,t).*thetav(:,t))/LS(t);

% TRADE BALANCE AND FOREIGN ASSETS
TB(t)   = Y(t)-C(t)-I(t)-J(t)-CG(t);
DF(t+1) = (1+r(t+1))*(DF(t)+TB(t))/G;

% GOVERNMENT
PB(t)    = DG(t)-G*DG(t+1)/(1+r(t+1));
Exp(t)   = CG(t)+B(t)+P(t);
Rev(t)   = TaxF(t)+(tauF(t)*LD(t)+tauW(t)*LS(t))*w(t)+taul(t)*N(t)+tauC(t)*C(t)+Nv(:,t)'*((1-notretv(:,t)).*tauWiv(:,t).*pv(:,t));

% EXCESS DEMANDS
edy(t)  = I(t)+J(t)+C(t)+CG(t)+TB(t)-Y(t);
edl(t)  = LD(t)-LS(t);
edg(t)  = Rev(t)-Exp(t)-PB(t);
eda(t)  = DF(t)+DG(t)+V(t)-A(t);
eda(t+1)= DF(t+1)+DG(t+1)+V(t+1)-A(t+1);
ediv(t) = -Nv(:,t)'*ivv(:,t);
edab(t) = Nv(:,t)'*((1-gamv(:,t)).*Savv)-ab(t);

% WALRAS LAW
edv(t)  = edy(t)+w(t)*edl(t)+edg(t)+ediv(t)+edab(t)+eda(t)-G*eda(t+1)/(1+r(t+1));
if abs(edv(t))> 1e-9; error('Error in TE.m: Walras Law does not hold!'); end

resid(1,1) = edl(t);
resid(2,1) = edg(t);
resid(3,1) = edab(t);

end

