% ----------------------
% calib.m
% ----------------------
% calibrates the model
% ----------------------

% DATA AND CALIBRATION

global alpha A_0 K0 LS0 LD0 I0 J0 Div0 V0 A0 Q0 TB0
global parlv0 parlv1 parpv0 hcutv0 yv0 abv0 ab0
global pc0 TaxF0 Exp0 Rev0 PB0 DG0 tauW0 tauWi0 tauWc0
global Av0 Cv0 Qv0 Hv0 Omegav0 P0 B0 shareAv0

x0      = [-360 0.02 0.09 10]; % inital guess
[x1, retcode] = findroot(@findcalib,x0');
if retcode~=0 error('Root finder in calib did not converge!'); end

global DF0 cG0 CG0 taul0 edy0 edl0 edg0 eda0 ediv0 edab0
DF0     = x1(1);
cG0     = x1(2); CG0 = cG0*N0;
taul0   = x1(3);
ab0     = x1(4);
edy0    = I0+J0+C0+CG0+TB0-Y0;
edl0    = LD0-LS0;
edg0    = Rev0-Exp0-PB0;
eda0    = V0+DF0+DG0-A0;
ediv0   = -Nv0'*ivv0;
edab0   = sum((1-gamv0).*(Av0+yv0+ivv0+abv0-pc0*Cv0).*Nv0)-ab0;
checkA0 = sum(Av0.*Nv0)-A0;
checkAv0= Av0(nag)+yv0(nag)+ivv0(nag)+abv0(nag)-pc0*Cv0(nag); % end of period assets of last age group are zero
checkN0 = sum(Nv0)-N0;

fprintf('DEPENDENCY RATIO: \t\t %4.5f\n\n',(Nv0'*(1-notretv0))/(Nv0'*notretv0));
fprintf('CHECK CALIBRATION: \t\t %4.5f\n',sum(abs([edy0,edl0,edg0,eda0,ediv0,edab0,checkA0,checkAv0,checkN0])));

% WRITE CALIBRATION TO LATEX-FILE
writecalib2latex;

% TIME SERIES INITIALIZATIONS

global Y Div w I J V K A edl C TB DF edy N ellv LS LD 
global partv hcutv yv Qv Cv Omegav Av Nv Hv IVv ivv NB r 
global gamv thetav notretv P B ab abv shareAv tauWiv tauWcv tauWv
global tauW tauWi tauWc tauF tauFi tauFc taul tauprof tauprofdeduct 
global tauC bv pv CG cG pc TaxF Exp Rev PB DG DGtarget edg eda edv ediv edab nwg

Y       = zeros(1,tend); Div = Y; w = Y; I = Y; J = Y; V = Y; CG = Y;
K       = Y; A = Y; C = Y; TB = Y; DF = Y; edy = Y; eda = Y;
N       = Y; LS = Y; LD = Y; edl = Y; edv = Y; B = Y; P = Y; ab = Y;
TaxF    = Y; Exp = Y; Rev = Y; PB = Y; edg = Y; ediv = Y; edab = Y;

Hv      = zeros(nag,tend); Cv = Hv; Qv = Hv; yv = Hv; ellv = Hv; shareAv = Hv;
Omegav  = Hv; partv = Hv; hcutv = Hv; Av = Hv; IVv = Hv; abv = Hv;

r       = r0*ones(1,tend); NB = NB0*ones(1,tend); N = N0*ones(1,tend); 
taul    = taul0*ones(1,tend); tauprof = tauprof0*ones(1,tend); tauF = tauF0*ones(1,tend);
tauprofdeduct = tauprofdeduct0*ones(1,tend); tauC = tauC0*ones(1,tend);
pc      = pc0*ones(1,tend); cG = cG0*ones(1,tend); DG = DG0*ones(1,tend);
DGtarget= DG0*ones(1,tend); tauW = tauW0*ones(1,tend); nwg = nwg0*ones(1,tend);
tauWi   = tauWi0*ones(1,tend); tauWc = tauWc0*ones(1,tend);
tauFi   = tauFi0*ones(1,tend); tauFc = tauFc0*ones(1,tend);

bv      = kron(bv0,ones(1,tend)); tauWv = kron(tauWv0,ones(1,tend));
gamv    = kron(gamv0,ones(1,tend)); thetav = kron(thetav0,ones(1,tend));
notretv = kron(notretv0,ones(1,tend)); ivv = kron(ivv0,ones(1,tend));
pv      = kron(pv0,ones(1,tend)); Nv = kron(Nv0,ones(1,tend));
tauWiv  = kron(tauWiv0,ones(1,tend)); tauWcv = kron(tauWcv0,ones(1,tend));

% CHECK SETTINGS
if (rem(budget_bal,1)~=0||budget_bal<1||budget_bal>6)
    error('Error: Enter a budget_bal between 1 and 6'); end

% REPLICATE INTIAL CALIBRATION
x0SS    = ones(4,1); x0TE = ones(3,1);
t       = 1; fprintf('\nREPLICATE SS: \t\t\t %4.5f\n', sum(abs(SS(x0SS))));
t       = 2; sum(abs(SS(x0SS)));
t       = 1; fprintf('REPLICATE TE: \t\t\t %4.5f\n\n', sum(abs(TE(x0TE))));

% TAKE INITIAL STEADY STATE AS GUESS FOR JACOBIAN
guess   = kron([V(t) Hv(:,t)' Omegav(:,t)'],ones(tend,1));
