% ----------------------
% findcalib.m
% ----------------------
% computes calibration
% in:   foreignassets
% out:  resid
% ----------------------

function resid = findcalib(inputs)

    global nag gamv0 r0 rho g G sigma psi delta w0 thetav0 N0 Nv0 Y0 
    global A_0 alpha Hv0 A0 K0 LS0 LD0 I0 J0 Div0 V0 Omegav0 C0 TB0
    global epsl parlv0 parlv1 parpv0 epsp yv0 abv0
    global tauW0 tauF0 tauprof0 tauprofdeduct0 tauC0 bv0
    global pc0 TaxF0 Exp0 Rev0 PB0 DG0 B0 P0
    global Av0 Cv0 Qv0 ellv0 partv0 tauWiv0 tauWcv0 tauWi0 tauWc0
    global notretv0 ivv0 pv0 tauWv0 shareAv0
    
    DF0     = inputs(1);
    cG0     = inputs(2);
    taul0   = inputs(3);
    ab0     = inputs(4);
    
    abv0    = ab0./N0.*ones(nag,1);
    
    pc0     = 1+tauC0;
   
    % CALIBRATION OF LABOR SUPPLY MARGINS
    
    % set parl0 in order to reprodcue ell0, FOC ell0
    parlv0  = ((1-tauWv0).*w0.*thetav0./pc0)./ellv0.^(1/epsl);
    % set parl1 in order to normalize effort costs to 0
    parlv1  = parlv0.*(epsl/(1+epsl)).*ellv0.^((1+epsl)/epsl);
    dis_ellv= parlv0.*(epsl/(1+epsl)).*ellv0.^((1+epsl)/epsl)-parlv1;
    
    hcutv0  = ((1-tauWv0).*w0.*thetav0.*ellv0-bv0)./pc0-dis_ellv;
    % set parp0 in order to reprodce part0
    parpv0  = ((1-partv0)./hcutv0.^(-epsp)).^(1/epsp);
    hexpv   = 1./partv0.*epsp./(1+epsp).*(parpv0.^epsp.*hcutv0.^(1-epsp)-parpv0);
    dis_totv= notretv0.*(partv0.*dis_ellv-(1-partv0).*hexpv);
        
    LS0     = sum(notretv0.*partv0.*ellv0.*thetav0.*Nv0);
    LD0     = LS0;
    uck     = (r0+delta*(1-tauprofdeduct0*tauprof0))/(1-tauprof0);
    K0      = (Y0-(1+tauF0)*w0*LD0)/uck;
    I0      = (delta+g)*K0;
    J0      = 1/2*psi*K0*(I0/K0-delta-g)^2;
    alpha   = uck*K0/Y0;
    A_0     = Y0/(K0^alpha*LS0^(1-alpha));
    LD0     = ((1-alpha)*A_0/((1+tauF0)*w0))^(1/alpha)*K0;
    TaxF0   = tauprof0*(Y0-(1+tauF0)*w0*LD0-tauprofdeduct0*(J0+delta*K0));
    Div0    = Y0-(1+tauF0)*w0*LD0-I0-J0-TaxF0;
    V0      = (1+r0)*Div0/(r0-g);
    yv0     = notretv0.*(partv0.*(1-tauWv0).*w0.*ellv0.*thetav0+(1-partv0).*bv0)+(1-notretv0).*(1-tauWiv0).*pv0-taul0;
        
    % CONSUMPTION FOR ALL AGE GROUPS
    % marginal propensity to consume, human wealth, intervivo transfer wealth
    % solve backwards in age
    Omegav0(nag,1) = 1;
    Hv0(nag,1)     = yv0(nag)-dis_totv(nag).*pc0+ivv0(nag)+abv0(nag);
    
    for i=(nag-1):-1:1
        Omegav0(i,1) = 1+(1/(1+rho)*gamv0(i))^sigma.*((1+r0)*(pc0/pc0))^(sigma-1)*Omegav0(i+1);
        Hv0(i,1)     = yv0(i)-dis_totv(i)*pc0+ivv0(i)+abv0(i)+G*Hv0(i+1)/(1+r0);
    end
    
    % assets and consumption
    % solve forward in age
    Av0(1)  = 0;
    Qv0(1)  = (Av0(1)+Hv0(1))/(pc0*Omegav0(1));
    Cv0(1)  = Qv0(1)+dis_totv(1);
    
    for i=2:nag
        Av0(i,1)  = (1+r0)*(Av0(i-1)+yv0(i-1)+ivv0(i-1)+abv0(i-1)-pc0*Cv0(i-1))/G;
        Qv0(i,1)  = (Av0(i)+Hv0(i))/(pc0*Omegav0(i));
        Cv0(i,1)  = Qv0(i)+dis_totv(i);
    end
    Savv     = Av0+yv0+ivv0+abv0-pc0*Cv0;
        
    % AGGREGATION
    A0      = sum(Av0.*Nv0);
    shareAv0= (Av0.*Nv0)./A0;
    Cguess  = sum(Cv0.*Nv0);
    TB0     = -DF0*(r0-g)/(1+r0);
    B0      = sum(notretv0.*(1-partv0).*bv0.*Nv0);      % expend benefits
    P0      = sum((1-notretv0).*pv0.*Nv0);              % expend pensions
    Exp0    = cG0*N0+B0+P0;
    tauW0   = sum(tauWv0.*notretv0.*partv0.*ellv0.*thetav0.*Nv0)/LS0;
    tauWi0  = sum(tauWiv0.*notretv0.*partv0.*ellv0.*thetav0.*Nv0)/LS0;
    tauWc0  = sum(tauWcv0.*notretv0.*partv0.*ellv0.*thetav0.*Nv0)/LS0;
    Rev0    = TaxF0+(tauF0*LD0+tauW0*LS0)*w0+taul0*N0+tauC0*C0+sum((1-notretv0).*tauWiv0.*pv0.*Nv0);
    PB0     = DG0*(r0-g)/(1+r0);
    
    resid(1,1)   = I0+J0+C0+cG0*N0+TB0-Y0;
    resid(2,1)   = Rev0-Exp0-PB0;
    resid(3,1)   = Cguess-C0;
    resid(4,1)   = sum((1-gamv0).*Savv.*Nv0)-ab0;
end