% ----------------------
% ft.m
% ----------------------
% use fair taylor iterative updating
% in:   guess, tune0 (opt), tstart (opt), maxiter (opt), tol (opt)
% out:  actual, retcode
% ----------------------

function [actual, retcode] = ft(guess, varargin)

% default arguments
tune0   = 1;
tstart  = 1;
maxiter = 2000;
tol     = 1e-06;

if nargin > 1
    tune0   = cell2mat(varargin(1)); end
if nargin > 2
    tstart  = cell2mat(varargin(2)); end
if nargin > 3
    maxiter = cell2mat(varargin(3)); end
if nargin > 4
    tol     = cell2mat(varargin(4)); end
if nargin > 5
    error('At most 5 arguments allowed in ft().'); end

tend      = size(guess,1);
retcode   = 0;
iter      = 0;
tiny      = 1e-20;

tic;

fprintf('\nFAIR TAYLOR ALGORITHM ACTIVE! WAIT!\n');

while iter < maxiter

    iter = iter + 1;
    actual = path(guess,tstart);
    
    mis = sum((actual-guess).^2)'/tend;
    
    fprintf('Iteration and Log of miss/tol:  \t %2.0f \t %2.5f \n',[iter,max(log(tiny+mis./tol))]);  
    
    if max(mis-tol) < 0
        retcode = 1; break;
    end
    
    last_G = guess;
    
    guess  = actual*tune0 + last_G*(1-tune0);
    
end

actual = guess;

if retcode == 0
    fprintf('\nMaximum iteration limit reached!\n');
end

if retcode == 1
    if max((guess(tend)-guess(tend-1)).^2)>tol;
        retcode = 2;
        fprintf('\nNo full convergence to FSS!\n');
    else
        
    fprintf('\nConvergence!\n');
    end
end

toc;






