% ----------------------
% param.m
% ----------------------
% loads exogenous parameters
% ----------------------

global N0 Nv0 nag nwg0 gamv0 ivv0 rho r0 g G delta sigma epsl epsp

N0      = 100;                  % noramlized population size
nag     = 80;                   % number of age groups (indexing starts with 1 instead of 0)
nwg0    = 40;                   % number of working groups (until retirement)

compdemo;                       % compute demography and intervivo transfers (specify inside!)

rho     = .015;                 % discount rate
r0      = .04;                  % interest rate
g       = 0.015;                % exogenous growth rate
G       = 1+g;                  % exogenous growth factor
delta   = 0.1;                  % depreciation rate
sigma   = 0.25;                 % intertemporal elasticity of substitution
epsl    = 0.3;                  % labor supply elasticity (hours)
epsp    = 0.5;                  % participation elasticity

global L0 w0 thetav0 Y0 C0 psi ellv0 partv0 notretv0

L0      = 30;                   % total labor supply in eff. units
w0      = 2;                    % wage rate
thetav0 = 1.*ones(nag,1);       % labor productivity parameter
thetav0(1:nwg0) = 0.7:(1-0.7)/(nwg0-1):1;
thetav0(nwg0+1:nag) = 1:-(1-0.7)/(nag-nwg0-1):0.7;
Y0      = 100;                  % normalized output
C0      = 0.5*Y0;               % consumption share (calibrated using taul0)
psi     = 2;                    % scaling factor adjustment costs
partv0  = 0.7.*ones(nag,1);     % participation rate
notretv0= zeros(nag,1); notretv0(1:nwg0)=ones(nwg0,1);  % indicator for retirement
ellv0   = L0/sum(Nv0.*thetav0.*partv0.*notretv0).*ones(nag,1); % per capita labor supply

global tauWiv0 tauWcv0 nu tauWv0 tauFi0 tauFc0 tauF0 tauprof0 tauprofdeduct0 tauC0 bv0 DG0 pv0 t

tauWiv0 = 0.05.*ones(nag,1);    % income tax employee, retiree
tauWcv0 = 0.1.*ones(nag,1);     % pension contribution employee
nu      = 1;                    % pension contribution tax deductible?
tauWv0  = tauWiv0 + tauWcv0 - nu*tauWiv0.*tauWcv0; % total deductions workers
tauFi0  = 0.05;                 % wage tax firm
tauFc0  = 0.15;                 % pension contribution firm
tauF0   = tauFi0 + tauFc0;      % total wage related deducations firm
tauC0   = 0.2;                  % consumption tax
tauprof0= 0.1;                  % profit tax
tauprofdeduct0 = 1;             % capital maintenance costs deductible
bv0     = 0.4*(1-tauWv0).*w0.*ellv0.*ones(nag,1);   % non-work benefits
pv0     = 0.6*(1-tauWv0).*w0.*ellv0.*ones(nag,1);   % old-age pension
DG0     = 0.6*Y0;               % government debt level
% CG0 is used to balance budget in calibration

t       = 1;                    % time index

