% ----------------------
% path.m
% ----------------------
% computes the path of temporary equilibrium until tend
% in:   guess, tstart (opt), tstop (opt)
% out:  actual
% ----------------------

function actualout = path(guessin,tstart,tstop)

global t tend nag w0 tauWi0 tauFi0 tauC0 tauprof0 taul0 cG0
global w tauWi tauFi tauC tauprof taul cG budget_bal
global V Hv Omegav ab ab0

V        = guessin(:,1)';
Hv       = guessin(:,2:(nag+1))';
Omegav   = guessin(:,(nag+2):(2*nag+1))';

% COMPUTE ALL TEMPORARY EQUILIBRIA

if nargin < 3;
    tstop = tend;
end

if nargin > 1
    t = tstart;
else
    t = 1;
end

x0TE = ones(3,1);

while t < tstop
    
    if t > 1
        x0TE(1)      = w(t-1)/w0;
        % budget-instrument choice
        if budget_bal == 1; x0TE(2) = 1+tauWi(t-1)-tauWi0; end
        if budget_bal == 2; x0TE(2) = 1+tauFi(t-1)-tauFi0; end
        if budget_bal == 3; x0TE(2) = 1+tauC(t-1)-tauC0; end
        if budget_bal == 4; x0TE(2) = 1+taul(t-1)-taul0; end
        if budget_bal == 5; x0TE(2) = 1+tauprof(t-1)-tauprof0; end
        if budget_bal == 6; x0TE(2) = 1+cG(t-1)-cG0; end
                
        x0TE(3)      = ab(t-1)/ab0;
    end
    
    [x1, retcode] = findroot(@TE,x0TE);
    
    if retcode~=0 error('Root finder in path did not converge!'); end
    
    t   = t+1;
end

actual = [V; Hv; Omegav]';

actualout = actual;

end