% ----------------------
% runme.m
% ----------------------
% 'AuerbachKotlikoff': Chapter 6.1
% April 19, 2015 Philip Schuster
% 
% computes the transition of a shock
% in a simple Auerbach-Kotlikoff model (open economy)
% with intensive and extensive margin labor supply
% and a government and accidental bequests
% ----------------------

clear all;  % clear all variables
clc;        % clear screen

fprintf('AUERBACH-KOTLIKOFF MODEL OF OPEN ECONOMY - TRANSITIONAL DYNAMICS\n\n');

% DATA AND CALIBRATION
global tend findrootmethod budget_bal

findrootmethod  = 1;    % use simple Newton-Raphson method (=1)
tend            = 300;  % number of periods
budget_bal      = 1;    % budget balance rule
% 1.. tauW, 2.. tauF, 3.. tauC, 4.. taul, 5.. tauprof, 6.. cG

param; % loads exogenous parameters
calib; % calibrates the model

% COMPUTE JACOBIAN FOR DYNAMIC SOLUTION
jacob = compjacob(guess);

% COMPUTE INITIAL STEADY STATE
ISS;

% REFORMS
%K(1) = K0*0.98;
%bv = bv*1.03;
%tauWiv = tauWiv*1.05;
%thetav = thetav*1.05;
%pv = pv*1.015;
%DGtarget(2:30)      = DG0*(1+(0:1/(30-2):1)*0.1);
%DGtarget(31:tend)   = DG0*ones(1,tend-30)*1.1;

% gamvnew         = 1-0.885.^(nag:-1:1)';
% gamvnew(nag)    = 0;
% gamv            = kron(gamvnew,ones(1,tend));

%gamvnew         = 1-0.885.^(nag:-1:1)';
%gamv(:,1:30)    = gamvnew*(1/30:1/30:1)+gamv0*(1-(1/30:1/30:1));
%gamv(:,31:tend) = kron(gamvnew,ones(1,tend-30));

NB   = NB*0.98;
%nwg  = nwg+1.5;

% RECOMPUTE DEMOGRAPHY
recompdemo;

% COMPUTE FINAL STEADY STATE
FSS;

%load('goodguess.mat');

% SOLVE FOR TRANSITIONS
[actual, retcode] = gft(guess,jacob,0.9,0.9);   % Generalized Fair-Taylor
%[actual, retcode] = ft(guess);         % Original Fair-Taylor

guess = actual; save('goodguess.mat','guess');

% COMPUTE WELFARE CHANGES
welfare;
%welfareC;

