% ----------------------
% writecalib2latex.m
% ----------------------
% produces detailed LaTeX tables from calibration
% ----------------------

mpl0         = (1+tauF0)*w0;
mpk0         = (r0+delta*(1-tauprofdeduct0*tauprof0))/(1-tauprof0);
subsidyPAYG0 = P0-(tauWc0*w0*LS0+tauFc0*w0*LD0);
abgiven0     = sum((1-gamv0).*(Av0+yv0+ivv0+abv0-pc0*Cv0).*Nv0);
ivgiven0     = -sum(Nv0.*ivv0.*(ivv0<0));
ivreceived0  = sum(Nv0.*ivv0.*(ivv0>0));

% LaTeX-Header
X0 = '\\documentclass[10pt]{article}\n\\usepackage{caption}\n\\captionsetup{format=hang, labelfont=bf}\n\\begin{document}\n\n';

% Table 1: Production
X1 = '\\begin{table}[!h]\\begin{center}\n\\caption{Production}\n\\begin{tabular}{lr|lr}\\hline\n';
X1 = [X1, '\\multicolumn{2}{l|}{Production cost} & \\multicolumn{2}{r}{Absorption} \\\\ \\hline\n'];
X1 = [X1, sprintf('Wage related income & %4.3f & Private consumption & %4.3f ',[mpl0*LD0,C0]),'\\\\ \n'];
X1 = [X1, sprintf('Capital related income & %4.3f & Government consumption & %4.3f ',[mpk0*K0,CG0]),'\\\\ \n'];
X1 = [X1, sprintf(' & & Capital investment & %4.3f ',[I0]),'\\\\ \n'];
X1 = [X1, sprintf(' & & Trade balance & %4.3f ',[TB0]),'\\\\ \\hline \n'];
X1 = [X1, sprintf('GDP & %4.3f & GDP & %4.3f ',[mpl0*LD0+mpk0*K0,C0+CG0+I0+TB0]),'\\\\ \\hline \n'];
X1 = [X1, '\\end{tabular}\\end{center}\\end{table}\\bigskip\n\n'];

% Table 2: Business Sector
X2 = '\\begin{table}[!h]\\begin{center}\n\\caption{Business Sector}\n\\begin{tabular}{lr|lr}\\hline\n';
X2 = [X2, '\\multicolumn{2}{l|}{Expenditure} & \\multicolumn{2}{r}{Income} \\\\ \\hline\n'];
X2 = [X2, sprintf('Wages & %4.3f & Output & %4.3f ',[w0*LD0,Y0]),'\\\\ \n'];
X2 = [X2, sprintf('Dividends & %4.3f &  & ',[Div0]),'\\\\ \n'];
X2 = [X2, sprintf('Capital investment & %4.3f & & ',[I0]),'\\\\ \n'];
X2 = [X2, sprintf('Corporate taxes & %4.3f & & ',[TaxF0]),'\\\\ \n'];
X2 = [X2, sprintf('Firm PAYG contributions & %4.3f & & ',[tauFc0*w0*LD0]),'\\\\ \n'];
X2 = [X2, sprintf('Firm pay-roll taxes & %4.3f & & ',[tauFi0*w0*LD0]),'\\\\ \\hline \n'];
X2 = [X2, sprintf('Total & %4.3f & Total & %4.3f ',[w0*LD0+Div0+TaxF0+I0+(tauFc0+tauFi0)*w0*LD0,Y0]),'\\\\ \\hline \n'];
X2 = [X2, '\\end{tabular}\\end{center}\\end{table}\\bigskip\n\n'];

% Table 3: Household Sector
X3 = '\\begin{table}[!h]\\begin{center}\n\\caption{Household Sector}\n\\begin{tabular}{lr|lr}\\hline\n';
X3 = [X3, '\\multicolumn{2}{l|}{Expenditure} & \\multicolumn{2}{r}{Income} \\\\ \\hline\n'];
X3 = [X3, sprintf('Private Consumption & %4.3f & Wages & %4.3f ',[C0,w0*LS0]),'\\\\ \n'];
X3 = [X3, sprintf('Households PAYG contr. & %4.3f & Publ. transfers to households & %4.3f',[tauWc0*w0*LS0,-taul0*N0]),'\\\\ \n'];
X3 = [X3, sprintf('Income tax workers & %4.3f & PAYG Pensions & %4.3f',[(tauW0-tauWc0)*w0*LS0,P0]),'\\\\ \n'];
X3 = [X3, sprintf('Income tax retirees & %4.3f & Non-part. benefits & %4.3f',[sum((1-notretv0).*tauWiv0.*pv0.*Nv0),B0]),'\\\\ \n'];
X3 = [X3, sprintf('Consumption taxes & %4.3f & Dividends & %4.3f',[tauC0*C0,Div0]),'\\\\ \n'];
X3 = [X3, sprintf('Accid. bequests given & %4.3f & Accid. bequests rec. & %4.3f',[abgiven0,ab0]),'\\\\ \n'];
X3 = [X3, sprintf('Intervivo trans. given & %4.3f & Intervivo trans. rec. & %4.3f',[ivgiven0,ivreceived0]),'\\\\ \n'];
X3 = [X3, sprintf('Private savings & %4.3f & Private interest earnings & %4.3f',[g*(A0-V0)/(1+r0),r0*(A0-V0)/(1+r0)]),'\\\\ \\hline \n'];
X3 = [X3, sprintf('Total & %4.3f & Total & %4.3f ',[C0+tauW0*w0*LS0+sum((1-notretv0).*tauWiv0.*pv0.*Nv0)]+tauC0*C0+abgiven0+ivgiven0+g*(A0-V0)/(1+r0),w0*LS0-taul0*N0+P0+B0+Div0+ab0+ivreceived0+r0*(A0-V0)/(1+r0)),'\\\\ \\hline \n'];
X3 = [X3, '\\end{tabular}\\end{center}\\end{table}\\bigskip\n\n'];

% Table 4: Government Sector
X4 = '\\begin{table}[!h]\\begin{center}\n\\caption{Government Sector}\n\\begin{tabular}{lr|lr}\\hline\n';
X4 = [X4, '\\multicolumn{2}{l|}{Expenditure} & \\multicolumn{2}{r}{Income} \\\\ \\hline\n'];
X4 = [X4, sprintf('Government Consumption & %4.3f & Income tax workers & %4.3f ',[CG0,(tauW0-tauWc0)*w0*LS0]),'\\\\ \n'];
X4 = [X4, sprintf('Publ. transfers to households & %4.3f & Income tax retirees & %4.3f ',[-taul0*N0,sum((1-notretv0).*tauWiv0.*pv0.*Nv0)]),'\\\\ \n'];
X4 = [X4, sprintf('Non-part. benefits & %4.3f & Firm pay-roll taxes & %4.3f ',[B0,tauFi0*w0*LD0]),'\\\\ \n'];
X4 = [X4, sprintf('Subsidy PAYG system & %4.3f & Corporate taxes & %4.3f ',[subsidyPAYG0,TaxF0]),'\\\\ \n'];
X4 = [X4, sprintf('Interest payments & %4.3f & Consumption taxes & %4.3f ',[r0*DG0/(1+r0),tauC0*C0]),'\\\\ \n'];
X4 = [X4, sprintf(' & & Net fiscal deficit & %4.3f ',[g*DG0/(1+r0)]),'\\\\ \\hline \n'];
X4 = [X4, sprintf('Total & %4.3f & Total & %4.3f ',[CG0-taul0*N0+B0+subsidyPAYG0+r0*DG0/(1+r0),(tauW0-tauWc0)*w0*LS0+sum((1-notretv0).*tauWiv0.*pv0.*Nv0)+tauFi0*w0*LD0+TaxF0+tauC0*C0+g*DG0/(1+r0)]),'\\\\ \\hline \n'];
X4 = [X4, '\\end{tabular}\\end{center}\\end{table}\\bigskip\n\n'];

% Table 5: PAYG Pension System
X5 = '\\begin{table}[!h]\\begin{center}\n\\caption{PAYG Pension System}\n\\begin{tabular}{lr|lr}\\hline\n';
X5 = [X5, '\\multicolumn{2}{l|}{Expenditure} & \\multicolumn{2}{r}{Income} \\\\ \\hline\n'];
X5 = [X5, sprintf('PAYG Pensions & %4.3f & Households PAYG contr. & %4.3f ',[P0,tauWc0*w0*LS0]),'\\\\ \n'];
X5 = [X5, sprintf(' & & Firm PAYG contributions & %4.3f ',[tauFc0*w0*LD0]),'\\\\ \n'];
X5 = [X5, sprintf(' & & Subsidy PAYG system & %4.3f ',[subsidyPAYG0]),'\\\\ \\hline \n'];
X5 = [X5, sprintf('Total & %4.3f & Total & %4.3f ',[P0,tauWc0*w0*LS0+tauFc0*w0*LD0+subsidyPAYG0]),'\\\\ \\hline \n'];
X5 = [X5, '\\end{tabular}\\end{center}\\end{table}\\bigskip\n\n'];

% Table 6: Current Account
X6 = '\\begin{table}[!h]\\begin{center}\n\\caption{Current Account}\n\\begin{tabular}{lr|lr}\\hline\n';
X6 = [X6, '\\multicolumn{2}{l|}{Expenditure} & \\multicolumn{2}{r}{Income} \\\\ \\hline\n'];
X6 = [X6, sprintf('Net foreign savings & %4.3f & Trade balance & %4.3f ',[g*DF0/(1+r0),TB0]),'\\\\ \n'];
X6 = [X6, sprintf(' & & Foreign interest earnings & %4.3f ',r0*DF0/(1+r0)),'\\\\ \\hline \n'];
X6 = [X6, sprintf('Total & %4.3f & Total & %4.3f ',[g*DF0/(1+r0),TB0+r0*DF0/(1+r0)]),'\\\\ \\hline \n'];
X6 = [X6, '\\end{tabular}\\end{center}\\end{table}\\bigskip\n\n'];

% LaTeX-Footer
Xend = '\\end{document}\n';

%fprintf([X0,X1,X2,X3,X4,X5,X6,Xend]);

fileID = fopen('tex/calibration.tex','w');
fprintf(fileID,[X0,X1,X2,X3,X4,X5,X6,Xend]);
fclose(fileID);